summaryrefslogtreecommitdiff
path: root/cipher
diff options
context:
space:
mode:
authorWerner Koch <wk@gnupg.org>2007-08-22 09:11:06 +0000
committerWerner Koch <wk@gnupg.org>2007-08-22 09:11:06 +0000
commitd6524c799ba7b65fd77458eaa2ba831dbbeb9163 (patch)
tree9962762f494e990512d507c32b3d9d0d554fc29e /cipher
parentdb6a84d79e4293194dfa0f68f7ac7dc66bb9c5d5 (diff)
downloadlibgcrypt-d6524c799ba7b65fd77458eaa2ba831dbbeb9163.tar.gz
Changed rndw32 to LGPL.
Typo fixes.
Diffstat (limited to 'cipher')
-rw-r--r--cipher/ChangeLog4
-rw-r--r--cipher/md.c6
-rw-r--r--cipher/rndw32.c40
3 files changed, 39 insertions, 11 deletions
diff --git a/cipher/ChangeLog b/cipher/ChangeLog
index da784fd6..e3274172 100644
--- a/cipher/ChangeLog
+++ b/cipher/ChangeLog
@@ -1,3 +1,7 @@
+2007-08-22 Werner Koch <wk@g10code.com>
+
+ * rndw32.c: Switched tpo LGPL.
+
2007-05-30 Werner Koch <wk@g10code.com>
* camellia.h, camellia.c: Replace by new LGPL version and adjusted
diff --git a/cipher/md.c b/cipher/md.c
index 28860135..e1cb27dd 100644
--- a/cipher/md.c
+++ b/cipher/md.c
@@ -885,7 +885,7 @@ md_read( gcry_md_hd_t a, int algo )
{
/* return the first algorithm */
if (r && r->next)
- log_debug("more than algorithm in md_read(0)\n");
+ log_debug ("more than one algorithm in md_read(0)\n");
return r->digest->read( &r->context.c );
}
else
@@ -1133,7 +1133,7 @@ gcry_md_algo_info (int algo, int what, void *buffer, size_t *nbytes)
memcpy (buffer, asn, asnlen);
*nbytes = asnlen;
}
- else if ((! buffer) && nbytes)
+ else if (!buffer && nbytes)
*nbytes = asnlen;
else
{
@@ -1200,7 +1200,7 @@ md_stop_debug( gcry_md_hd_t md )
* Returns 1 when the handle works on secured memory
* otherwise 0 is returned. There is no error return.
* GCRYCTL_IS_ALGO_ENABLED:
- * Returns 1 if the algo is enanled for that handle.
+ * Returns 1 if the algo is enabled for that handle.
* The algo must be passed as the address of an int.
*/
gcry_error_t
diff --git a/cipher/rndw32.c b/cipher/rndw32.c
index d21dc128..e5c864e2 100644
--- a/cipher/rndw32.c
+++ b/cipher/rndw32.c
@@ -34,15 +34,38 @@
* author, <pgut001@cs.auckland.ac.nz> to allow them to be added to the
* baseline version of the code.
*
* ALTERNATIVELY, the code may be distributed under the terms of the GNU
* General Public License, version 2 or any later version published by the
* Free Software Foundation, in which case the provisions of the GNU GPL are
* required INSTEAD OF the above restrictions.
*
* Although not required under the terms of the GPL, it would still be nice if
* you could make any changes available to the author to allow a consistent
* code base to be maintained
*************************************************************************
+ * The above alternative was changed from GPL to LGPL on 2007-08-22 with
+ * permission from Peter Gutmann:
+ *==========
+ From: pgut001 <pgut001@cs.auckland.ac.nz>
+ Subject: Re: LGPL for the windows entropy gatherer
+ To: wk@gnupg.org
+ Date: Wed, 22 Aug 2007 03:05:42 +1200
+
+ Hi,
+
+ >As of now libgcrypt is GPL under Windows due to that module and some people
+ >would really like to see it under LGPL too. Can you do such a license change
+ >to LGPL version 2? Note that LGPL give the user the option to relicense it
+ >under GPL, so the change would be pretty easy and backwar compatible.
+
+ Sure. I assumed that since GPG was GPLd, you'd prefer the GPL for the entropy
+ code as well, but Ian asked for LGPL as an option so as of the next release
+ I'll have LGPL in there. You can consider it to be retroactive, so your
+ current version will be LGPLd as well.
+
+ Peter.
+ *==========
*/
#include <config.h>
@@ -481,7 +504,8 @@ slow_gatherer_windowsNT( void (*add)(const void*, size_t, int), int requester )
pPerfData = gcry_realloc (pPerfData, cbPerfData);
}
else {
- log_debug ( "rndw32: get performance data problem\n");
+ log_debug ("rndw32: get performance data problem: ec=%ld\n",
+ status);
break;
}
}
@@ -34,15 +34,38 @@
* baseline version of the code.
*
- * ALTERNATIVELY, the code may be distributed under the terms of the GNU
- * General Public License, version 2 or any later version published by the
- * Free Software Foundation, in which case the provisions of the GNU GPL are
- * required INSTEAD OF the above restrictions.
+ * ALTERNATIVELY, the code may be distributed under the terms of the
+ * GNU Lesser General Public License, version 2.1 or any later version
+ * published by the Free Software Foundation, in which case the
+ * provisions of the GNU LGPL are required INSTEAD OF the above
+ * restrictions.
*
@@ -34,15 +34,38 @@
*
- * Although not required under the terms of the GPL, it would still be nice if
- * you could make any changes available to the author to allow a consistent
- * code base to be maintained
+ * Although not required under the terms of the LGPL, it would still
+ * be nice if you could make any changes available to the author to
+ * allow a consistent code base to be maintained.
*************************************************************************